import { select, scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon', 'kiwi'])
  .range(['#c11d1d', '#eae600', '#ad603c']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon', 'kiwi'])
  .range([80, 50, 30]);

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('width', 920)
      .attr('height', 300)
      .attr('rx', 300 / 2);
  
  const groups = selection.selectAll('g')
    .data(fruits);
  
  const groupsEnter = groups.enter().append('g');
  
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(${i * 180 + 100}, ${height / 2})`
      );
  
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('fill', d => colorScale(d.type))
    .transition()
      .attr('r', d => radiusScale(d.type));
  
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y', 120)
    // text update
    .transition().duration(2000)
      .style('opacity', 0.2);
  
  // circle exit transition
  groups.exit()
    .select('circle')
      .transition().duration(1100)
        .attr('r', 0)
    .remove();
  
  // text exit transition
  groups.exit()
    .select('text')
      .transition().duration(1000)
        .style('opacity', 0)
    .remove();

};